[Crash-utility] [PATCH] arm64: exclude mapping symbols in modules

AKASHI Takahiro takahiro.akashi at linaro.org
Tue Oct 4 01:55:17 UTC 2016


If some module has been inserted, crash util complains about
module symbols:
    ...
    please wait... (gathering module symbol data)
    crash: store_module_symbols_v2: total: 15 mcnt: 16
and end up with stopping.

This patch excludes mapping symbols, like $d and $x, as arm does.

Signed-off-by: AKASHI Takahiro <takahiro.akashi at linaro.org>
---
 symbols.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/symbols.c b/symbols.c
index 99c8b8b..a657ead 100644
--- a/symbols.c
+++ b/symbols.c
@@ -2251,10 +2251,11 @@ store_module_kallsyms_v2(struct load_module *lm, int start, int curr,
 			continue;
 
 		/*
 		 * On ARM we have linker mapping symbols like '$a' and '$d'.
 		 * Make sure that these don't end up into our symbol list.
 		 */
-		if (machine_type("ARM") &&
+		if ((machine_type("ARM") || machine_type("ARM64")) &&
 		    !machdep->verify_symbol(nameptr, ec->st_value, ec->st_info))
 			continue;
 
@@ -2251,10 +2251,11 @@ store_module_kallsyms_v2(struct load_module *lm, int start, int curr,
 
 		/*
-		 * On ARM we have linker mapping symbols like '$a' and '$d'.
+		 * On ARM/ARM64 we have linker mapping symbols like '$a'
+		 * or '$x' for ARM64, and '$d'.
 		 * Make sure that these don't end up into our symbol list.
 		 */
-- 
2.10.0




More information about the Crash-utility mailing list